==> koffice-trinity_3.5.13.2.orig.tar.xz: koffice-trinity-3.5.13.2/chalk/plugins/tools/tool_filter/kis_tool_filter.h <==
/*
 *  kis_tool_filter.h - part of Chalk
 *
 *  Copyright (c) 2004 Cyrille Berger <cberger@cberger.net>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 */

#ifndef __KIS_TOOL_FILTER_H__
#define __KIS_TOOL_FILTER_H__

#include "kis_tool_freehand.h"
#include "kis_tool_factory.h"

class TQComboBox;
class TQGridLayout;
class KisEvent;
class KisFilterConfigurationWidget;
class KisButtonPressEvent;
class KisView;
class KisID;
class KisCmbIDList;


class KisToolFilter : public KisToolFreehand {
    Q_OBJECT
  TQ_OBJECT
    typedef KisToolFreehand super;

public:
    KisToolFilter();
    virtual ~KisToolFilter();

    virtual void setup(KActionCollection *collection);
    virtual enumToolType toolType() { return TOOL_FREEHAND; }
    virtual TQ_UINT32 priority() { return 1; }
    virtual TQWidget* createOptionWidget(TQWidget* parent);

public slots:
    void changeFilter( const KisID & filter);

protected:
    virtual void initPaint(KisEvent *e);

private:
    KisFilterSP m_filter;
    TQWidget* m_filterConfigurationWidget;
    TQGridLayout* m_optionLayout;
    KisCmbIDList * m_cbFilter;
};


class KisToolFilterFactory : public KisToolFactory {
    typedef KisToolFactory super;
public:
    KisToolFilterFactory() : super() {};
    virtual ~KisToolFilterFactory(){};

    virtual KisTool * createTool(KActionCollection * ac) {
        KisTool * t =  new KisToolFilter();
        Q_CHECK_PTR(t);
        t->setup(ac);
        return t;
    }
    virtual KisID id() { return KisID("filter", i18n("Filter Tool")); }
};

#endif //__KIS_TOOL_FILTER_H__

==> koffice-trinity-14.0.13.tar.xz: koffice-trinity-14.0.13/chalk/plugins/tools/tool_filter/kis_tool_filter.h <==
/*
 *  kis_tool_filter.h - part of Chalk
 *
 *  Copyright (c) 2004 Cyrille Berger <cberger@cberger.net>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 */

#ifndef __KIS_TOOL_FILTER_H__
#define __KIS_TOOL_FILTER_H__

#include "kis_tool_freehand.h"
#include "kis_tool_factory.h"

class TQComboBox;
class TQGridLayout;
class KisEvent;
class KisFilterConfigurationWidget;
class KisButtonPressEvent;
class KisView;
class KisID;
class KisCmbIDList;


class KisToolFilter : public KisToolFreehand {
    Q_OBJECT
  
    typedef KisToolFreehand super;

public:
    KisToolFilter();
    virtual ~KisToolFilter();

    virtual void setup(TDEActionCollection *collection);
    virtual enumToolType toolType() { return TOOL_FREEHAND; }
    virtual TQ_UINT32 priority() { return 1; }
    virtual TQWidget* createOptionWidget(TQWidget* parent);

public slots:
    void changeFilter( const KisID & filter);

protected:
    virtual void initPaint(KisEvent *e);

private:
    KisFilterSP m_filter;
    TQWidget* m_filterConfigurationWidget;
    TQGridLayout* m_optionLayout;
    KisCmbIDList * m_cbFilter;
};


class KisToolFilterFactory : public KisToolFactory {
    typedef KisToolFactory super;
public:
    KisToolFilterFactory() : super() {};
    virtual ~KisToolFilterFactory(){};

    virtual KisTool * createTool(TDEActionCollection * ac) {
        KisTool * t =  new KisToolFilter();
        TQ_CHECK_PTR(t);
        t->setup(ac);
        return t;
    }
    virtual KisID id() { return KisID("filter", i18n("Filter Tool")); }
};

#endif //__KIS_TOOL_FILTER_H__
